/*
 * Pan - A Newsreader for X
 * Copyright (C) 1999, 2000, 2001  Pan Development Team (pan@superpimp.org)
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 */

#ifndef __FILE_HEADERS_H__
#define __FILE_HEADERS_H__

#include <stdio.h>
#include <glib.h>
#include "group.h"
#include "status-item.h"

void     file_headers_destroy          (const Group * group);

void     file_headers_load             (Group * group, StatusItem * status);

void     file_headers_save             (Group * group, StatusItem * status);



 
long     get_string_offset             (GHashTable * hash, GMemChunk * long_chunk, const gchar * str, FILE * fp, glong * pos);

#endif
